# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/permission_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.acl import action_pb2 as eolymp_dot_acl_dot_action__pb2
from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/acl/permission_service.proto\x12\neolymp.acl\x1a\x17\x65olymp/acl/action.proto\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\".\n\x1aIntrospectPermissionsInput\x12\x10\n\x08resource\x18\x01 \x01(\t\"B\n\x1bIntrospectPermissionsOutput\x12#\n\x07\x61\x63tions\x18\x01 \x03(\x0e\x32\x12.eolymp.acl.Action2\xa3\x01\n\x11PermissionService\x12\x8d\x01\n\x15IntrospectPermissions\x12&.eolymp.acl.IntrospectPermissionsInput\x1a\'.eolymp.acl.IntrospectPermissionsOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/permissionsB)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.permission_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _PERMISSIONSERVICE.methods_by_name['IntrospectPermissions']._options = None
  _PERMISSIONSERVICE.methods_by_name['IntrospectPermissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\016\"\014/permissions'
  _INTROSPECTPERMISSIONSINPUT._serialized_start=143
  _INTROSPECTPERMISSIONSINPUT._serialized_end=189
  _INTROSPECTPERMISSIONSOUTPUT._serialized_start=191
  _INTROSPECTPERMISSIONSOUTPUT._serialized_end=257
  _PERMISSIONSERVICE._serialized_start=260
  _PERMISSIONSERVICE._serialized_end=423
# @@protoc_insertion_point(module_scope)
