# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/runtime/runtime.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.runtime import language_pb2 as eolymp_dot_runtime_dot_language__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/runtime/runtime.proto\x12\x0e\x65olymp.runtime\x1a\x1d\x65olymp/runtime/language.proto\"\x83\x01\n\x07Runtime\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12+\n\x04type\x18\x04 \x01(\x0e\x32\x1d.eolymp.runtime.Language.Type\x12\x0c\n\x04name\x18\n \x01(\t\x12\x12\n\ndeprecated\x18\x0c \x01(\x08\x42\x31Z/github.com/eolymp/go-sdk/eolymp/runtime;runtimeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.runtime.runtime_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/runtime;runtime'
  _RUNTIME._serialized_start=80
  _RUNTIME._serialized_end=211
# @@protoc_insertion_point(module_scope)
