# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/action.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/acl/action.proto\x12\neolymp.acl*\x96\x05\n\x06\x41\x63tion\x12\x12\n\x0eUNKNOWN_ACTION\x10\x00\x12\x0e\n\nSPACE_LIST\x10\n\x12\x0e\n\nSPACE_READ\x10\x0b\x12\x0f\n\x0bSPACE_WRITE\x10\r\x12\x10\n\x0cSPACE_DELETE\x10\x10\x12\x10\n\x0c\x42ILLING_READ\x10\x0c\x12\x11\n\rBILLING_WRITE\x10\x0f\x12\x0f\n\x0bPOLICY_LIST\x10\x16\x12\x0f\n\x0bPOLICY_READ\x10\x14\x12\x10\n\x0cPOLICY_WRITE\x10\x15\x12\x10\n\x0cPROBLEM_LIST\x10\x1e\x12\x10\n\x0cPROBLEM_READ\x10\x1f\x12\x11\n\rPROBLEM_WRITE\x10$\x12\x13\n\x0fPROBLEM_TESTING\x10\"\x12\x10\n\x0c\x43ONTEST_LIST\x10\x32\x12\x10\n\x0c\x43ONTEST_READ\x10\x33\x12\x11\n\rCONTEST_WRITE\x10>\x12\x0f\n\x0bTICKET_LIST\x10H\x12\x0f\n\x0bTICKET_READ\x10\x46\x12\x10\n\x0cTICKET_WRITE\x10G\x12\x0f\n\x0bMEMBER_LIST\x10Z\x12\x0f\n\x0bMEMBER_READ\x10[\x12\x10\n\x0cMEMBER_WRITE\x10\\\x12\x13\n\x0fSCOREBOARD_LIST\x10n\x12\x13\n\x0fSCOREBOARD_READ\x10o\x12\x14\n\x10SCOREBOARD_WRITE\x10p\x12\x10\n\x0c\x43ONTENT_LIST\x10z\x12\x10\n\x0c\x43ONTENT_READ\x10x\x12\x11\n\rCONTENT_WRITE\x10y\x12\x10\n\x0b\x43OURSE_LIST\x10\x85\x01\x12\x10\n\x0b\x43OURSE_READ\x10\x82\x01\x12\x11\n\x0c\x43OURSE_WRITE\x10\x83\x01\x12\x12\n\rCOURSE_ASSIGN\x10\x84\x01\x12\x0e\n\tPOST_LIST\x10\x8e\x01\x12\x0e\n\tPOST_READ\x10\x8c\x01\x12\x0f\n\nPOST_WRITE\x10\x8d\x01\x42)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.action_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _ACTION._serialized_start=40
  _ACTION._serialized_end=702
# @@protoc_insertion_point(module_scope)
