# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/ranker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ranker import activity_pb2 as eolymp_dot_ranker_dot_activity__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/ranker/activity.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x84\x01\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\x12\x1b\n\x13\x61\x64\x64_default_columns\x18\x02 \x01(\x08\x12\x1f\n\x17\x64uplicate_scoreboard_id\x18\x03 \x01(\t\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\xdf\x01\n\x15UpdateScoreboardInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.ranker.UpdateScoreboardInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12-\n\nscoreboard\x18\x03 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"E\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x10\n\x0c\x44\x45\x46\x41ULT_SORT\x10\x03\x12\x0e\n\nHISTORICAL\x10\x04\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\".\n\x17RebuildScoreboardOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"H\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xa7\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x93\x01\n\x1a\x44\x65scribeScoreboardRowInput\x12\x34\n\x04mode\x18\n \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x0b \x01(\r\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"Y\n\x1b\x44\x65scribeScoreboardRowOutput\x12*\n\x03row\x18\x01 \x01(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"\xd3\x04\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.ranker.ListScoreboardRowsInput.Filter\x12\x0c\n\x04sort\x18\x32 \x01(\t\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xb4\x01\n\x10\x45xpressionColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x06string\x18\n \x01(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x06number\x18\x0b \x01(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12.\n\x04\x65num\x18\x0c \x01(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x1a\x84\x01\n\x06\x46ilter\x12\x31\n\tmember_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12G\n\x06\x63olumn\x18\x02 \x03(\x0b\x32\x37.eolymp.ranker.ListScoreboardRowsInput.ExpressionColumn\"g\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"c\n\x18\x41\x64\x64ScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\".\n\x19\x41\x64\x64ScoreboardColumnOutput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"\xb4\x02\n\x1bUpdateScoreboardColumnInput\x12?\n\x05patch\x18\x01 \x03(\x0e\x32\x30.eolymp.ranker.UpdateScoreboardColumnInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12\x11\n\tcolumn_id\x18\x03 \x01(\t\x12\x30\n\x06\x63olumn\x18\x04 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"x\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\r\n\tPARENT_ID\x10\x01\x12\x07\n\x03KEY\x10\x02\x12\x08\n\x04NAME\x10\x03\x12\x0e\n\nSHORT_NAME\x10\x04\x12\t\n\x05INDEX\x10\x05\x12\x0b\n\x07VISIBLE\x10\x06\x12\x0e\n\nFILTERABLE\x10\x07\x12\x0c\n\x08SORTABLE\x10\x08\"\x1e\n\x1cUpdateScoreboardColumnOutput\"G\n\x1b\x44\x65leteScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteScoreboardColumnOutput\"I\n\x1d\x44\x65scribeScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"R\n\x1e\x44\x65scribeScoreboardColumnOutput\x12\x30\n\x06\x63olumn\x18\x01 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"3\n\x1aListScoreboardColumnsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x1bListScoreboardColumnsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"J\n\x13ListActivitiesInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.ranker.Activity\"^\n\x13ScheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Action\")\n\x14ScheduleActionOutput\x12\x11\n\taction_id\x18\x01 \x01(\t\"A\n\x15UnscheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\taction_id\x18\x02 \x01(\t\"\x18\n\x16UnscheduleActionOutput\"2\n\x19ListScheduledActionsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\\\n\x1aListScheduledActionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Action2\xfe\x19\n\x06Ranker\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16UpdateScoreboardColumn\x12*.eolymp.ranker.UpdateScoreboardColumnInput\x1a+.eolymp.ranker.UpdateScoreboardColumnOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32\x1a\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columns\x12\xb3\x01\n\x0eListActivities\x12\".eolymp.ranker.ListActivitiesInput\x1a#.eolymp.ranker.ListActivitiesOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02)\x12\'/scoreboards/{scoreboard_id}/activities\x12\xb6\x01\n\x0eScheduleAction\x12\".eolymp.ranker.ScheduleActionInput\x1a#.eolymp.ranker.ScheduleActionOutput\"[\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\"%/scoreboards/{scoreboard_id}/schedule\x12\xc8\x01\n\x10UnscheduleAction\x12$.eolymp.ranker.UnscheduleActionInput\x1a%.eolymp.ranker.UnscheduleActionOutput\"g\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x33*1/scoreboards/{scoreboard_id}/schedule/{action_id}\x12\xc8\x01\n\x14ListScheduledActions\x12(.eolymp.ranker.ListScheduledActionsInput\x1a).eolymp.ranker.ListScheduledActionsOutput\"[\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\'\x12%/scoreboards/{scoreboard_id}/scheduleB/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.ranker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _RANKER.methods_by_name['CreateScoreboard']._options = None
  _RANKER.methods_by_name['CreateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\"\014/scoreboards'
  _RANKER.methods_by_name['UpdateScoreboard']._options = None
  _RANKER.methods_by_name['UpdateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['RebuildScoreboard']._options = None
  _RANKER.methods_by_name['RebuildScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _RANKER.methods_by_name['DeleteScoreboard']._options = None
  _RANKER.methods_by_name['DeleteScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['DescribeScoreboard']._options = None
  _RANKER.methods_by_name['DescribeScoreboard']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['ListScoreboards']._options = None
  _RANKER.methods_by_name['ListScoreboards']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\022\014/scoreboards'
  _RANKER.methods_by_name['DescribeScoreboardRow']._options = None
  _RANKER.methods_by_name['DescribeScoreboardRow']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _RANKER.methods_by_name['ListScoreboardRows']._options = None
  _RANKER.methods_by_name['ListScoreboardRows']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _RANKER.methods_by_name['AddScoreboardColumn']._options = None
  _RANKER.methods_by_name['AddScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['UpdateScoreboardColumn']._options = None
  _RANKER.methods_by_name['UpdateScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022\0320/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['DeleteScoreboardColumn']._options = None
  _RANKER.methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['DescribeScoreboardColumn']._options = None
  _RANKER.methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['ListScoreboardColumns']._options = None
  _RANKER.methods_by_name['ListScoreboardColumns']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['ListActivities']._options = None
  _RANKER.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002)\022\'/scoreboards/{scoreboard_id}/activities'
  _RANKER.methods_by_name['ScheduleAction']._options = None
  _RANKER.methods_by_name['ScheduleAction']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\'\"%/scoreboards/{scoreboard_id}/schedule'
  _RANKER.methods_by_name['UnscheduleAction']._options = None
  _RANKER.methods_by_name['UnscheduleAction']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0023*1/scoreboards/{scoreboard_id}/schedule/{action_id}'
  _RANKER.methods_by_name['ListScheduledActions']._options = None
  _RANKER.methods_by_name['ListScheduledActions']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\'\022%/scoreboards/{scoreboard_id}/schedule'
  _CREATESCOREBOARDINPUT._serialized_start=276
  _CREATESCOREBOARDINPUT._serialized_end=408
  _CREATESCOREBOARDOUTPUT._serialized_start=410
  _CREATESCOREBOARDOUTPUT._serialized_end=457
  _UPDATESCOREBOARDINPUT._serialized_start=460
  _UPDATESCOREBOARDINPUT._serialized_end=683
  _UPDATESCOREBOARDINPUT_PATCH._serialized_start=614
  _UPDATESCOREBOARDINPUT_PATCH._serialized_end=683
  _UPDATESCOREBOARDOUTPUT._serialized_start=685
  _UPDATESCOREBOARDOUTPUT._serialized_end=709
  _REBUILDSCOREBOARDINPUT._serialized_start=711
  _REBUILDSCOREBOARDINPUT._serialized_end=758
  _REBUILDSCOREBOARDOUTPUT._serialized_start=760
  _REBUILDSCOREBOARDOUTPUT._serialized_end=806
  _DELETESCOREBOARDINPUT._serialized_start=808
  _DELETESCOREBOARDINPUT._serialized_end=854
  _DELETESCOREBOARDOUTPUT._serialized_start=856
  _DELETESCOREBOARDOUTPUT._serialized_end=880
  _DESCRIBESCOREBOARDINPUT._serialized_start=882
  _DESCRIBESCOREBOARDINPUT._serialized_end=954
  _DESCRIBESCOREBOARDOUTPUT._serialized_start=956
  _DESCRIBESCOREBOARDOUTPUT._serialized_end=1029
  _LISTSCOREBOARDSINPUT._serialized_start=1032
  _LISTSCOREBOARDSINPUT._serialized_end=1199
  _LISTSCOREBOARDSINPUT_FILTER._serialized_start=1147
  _LISTSCOREBOARDSINPUT_FILTER._serialized_end=1199
  _LISTSCOREBOARDSOUTPUT._serialized_start=1201
  _LISTSCOREBOARDSOUTPUT._serialized_end=1281
  _DESCRIBESCOREBOARDROWINPUT._serialized_start=1284
  _DESCRIBESCOREBOARDROWINPUT._serialized_end=1431
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_start=1433
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_end=1522
  _LISTSCOREBOARDROWSINPUT._serialized_start=1525
  _LISTSCOREBOARDROWSINPUT._serialized_end=2120
  _LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN._serialized_start=1805
  _LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN._serialized_end=1985
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_start=1988
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_end=2120
  _LISTSCOREBOARDROWSOUTPUT._serialized_start=2122
  _LISTSCOREBOARDROWSOUTPUT._serialized_end=2225
  _ADDSCOREBOARDCOLUMNINPUT._serialized_start=2227
  _ADDSCOREBOARDCOLUMNINPUT._serialized_end=2326
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_start=2328
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_end=2374
  _UPDATESCOREBOARDCOLUMNINPUT._serialized_start=2377
  _UPDATESCOREBOARDCOLUMNINPUT._serialized_end=2685
  _UPDATESCOREBOARDCOLUMNINPUT_PATCH._serialized_start=2565
  _UPDATESCOREBOARDCOLUMNINPUT_PATCH._serialized_end=2685
  _UPDATESCOREBOARDCOLUMNOUTPUT._serialized_start=2687
  _UPDATESCOREBOARDCOLUMNOUTPUT._serialized_end=2717
  _DELETESCOREBOARDCOLUMNINPUT._serialized_start=2719
  _DELETESCOREBOARDCOLUMNINPUT._serialized_end=2790
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_start=2792
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_end=2822
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_start=2824
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_end=2897
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_start=2899
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_end=2981
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_start=2983
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_end=3034
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_start=3036
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_end=3129
  _LISTACTIVITIESINPUT._serialized_start=3131
  _LISTACTIVITIESINPUT._serialized_end=3205
  _LISTACTIVITIESOUTPUT._serialized_start=3207
  _LISTACTIVITIESOUTPUT._serialized_end=3284
  _SCHEDULEACTIONINPUT._serialized_start=3286
  _SCHEDULEACTIONINPUT._serialized_end=3380
  _SCHEDULEACTIONOUTPUT._serialized_start=3382
  _SCHEDULEACTIONOUTPUT._serialized_end=3423
  _UNSCHEDULEACTIONINPUT._serialized_start=3425
  _UNSCHEDULEACTIONINPUT._serialized_end=3490
  _UNSCHEDULEACTIONOUTPUT._serialized_start=3492
  _UNSCHEDULEACTIONOUTPUT._serialized_end=3516
  _LISTSCHEDULEDACTIONSINPUT._serialized_start=3518
  _LISTSCHEDULEDACTIONSINPUT._serialized_end=3568
  _LISTSCHEDULEDACTIONSOUTPUT._serialized_start=3570
  _LISTSCHEDULEDACTIONSOUTPUT._serialized_end=3662
  _RANKER._serialized_start=3665
  _RANKER._serialized_end=6991
# @@protoc_insertion_point(module_scope)
