# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/runtime/configuration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*eolymp/runtime/configuration_service.proto\x12\x0e\x65olymp.runtime\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\x1c\n\x1a\x44\x65scribeRuntimeConfigInput\"6\n\x1b\x44\x65scribeRuntimeConfigOutput\x12\x17\n\x0f\x61llowed_runtime\x18\x01 \x03(\t\"6\n\x1b\x43onfigureRuntimeConfigInput\x12\x17\n\x0f\x61llowed_runtime\x18\x01 \x03(\t\"\x1e\n\x1c\x43onfigureRuntimeConfigOutput2\xee\x02\n\x14\x43onfigurationService\x12\x99\x01\n\x15\x44\x65scribeRuntimeConfig\x12*.eolymp.runtime.DescribeRuntimeConfigInput\x1a+.eolymp.runtime.DescribeRuntimeConfigOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x12\x12\x10/configs/runtime\x12\xb9\x01\n\x16\x43onfigureRuntimeConfig\x12+.eolymp.runtime.ConfigureRuntimeConfigInput\x1a,.eolymp.runtime.ConfigureRuntimeConfigOutput\"D\x82\xe3\n\x19\x8a\xe3\n\x15runtime:runtime:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\x1a\x10/configs/runtimeB1Z/github.com/eolymp/go-sdk/eolymp/runtime;runtimeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.runtime.configuration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/runtime;runtime'
  _CONFIGURATIONSERVICE.methods_by_name['DescribeRuntimeConfig']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['DescribeRuntimeConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\022\022\020/configs/runtime'
  _CONFIGURATIONSERVICE.methods_by_name['ConfigureRuntimeConfig']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['ConfigureRuntimeConfig']._serialized_options = b'\202\343\n\031\212\343\n\025runtime:runtime:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\022\032\020/configs/runtime'
  _DESCRIBERUNTIMECONFIGINPUT._serialized_start=161
  _DESCRIBERUNTIMECONFIGINPUT._serialized_end=189
  _DESCRIBERUNTIMECONFIGOUTPUT._serialized_start=191
  _DESCRIBERUNTIMECONFIGOUTPUT._serialized_end=245
  _CONFIGURERUNTIMECONFIGINPUT._serialized_start=247
  _CONFIGURERUNTIMECONFIGINPUT._serialized_end=301
  _CONFIGURERUNTIMECONFIGOUTPUT._serialized_start=303
  _CONFIGURERUNTIMECONFIGOUTPUT._serialized_end=333
  _CONFIGURATIONSERVICE._serialized_start=336
  _CONFIGURATIONSERVICE._serialized_end=702
# @@protoc_insertion_point(module_scope)
